@@ -20,6 +20,14 @@ Rcpp.system.file <- function(...){
     tools::file_path_as_absolute( base::system.file( ..., package = "Rcpp" ) )
 }
 
+## quote path if non-standard characters are used
+Rcpp.quoteNonStandard <- function(path) {
+    ## On unix, check if path has only characters that do not need quoting
+    noquote <- .Platform$OS.type == "unix" && grepl("^[[:alnum:]/._~+@%-]*$", path)
+    ## If no quoting needed return unchanged else quote input
+    if (noquote) path else shQuote(path)
+}
+
 ## Use R's internal knowledge of path settings to find the lib/ directory
 ## plus optinally an arch-specific directory on system building multi-arch
 RcppLdPath <- function() {
@@ -51,7 +59,7 @@ RcppCxxFlags <- function(cxx0x=FALSE) {
     if (.Platform$OS.type=="windows") {
         path <- asBuildPath(path)				# #nocov
     }
-    paste0('-I"', path, '"')
+    paste0('-I', Rcpp.quoteNonStandard(path))
 }
 
 ## Shorter names, and call cat() directly
