@@ -28,6 +28,7 @@
 // #define RCPP_DEBUG_MODULE_LEVEL 1
 
 #include <Rcpp/r/headers.h>
+#include <Rcpp/r/compat.h>
 
 /**
  * \brief Rcpp API
@@ -53,6 +54,9 @@ namespace Rcpp {
 #include <iomanip>
 #include <sstream>
 #include <string>
+#if __cplusplus >= 201703L
+#include <string_view>
+#endif
 #include <list>
 #include <map>
 #include <set>
